.. title:: User guide: contents

.. _user_guide:

==========
User Guide
==========

.. Ensure that the references will be alphabetically collected last
.. Check https://github.com/mcmtroffaes/sphinxcontrib-bibtex/issues/113

.. toctree::
   :numbered:

   introduction.rst
   over_sampling.rst
   under_sampling.rst
   combine.rst
   ensemble.rst
   miscellaneous.rst
   metrics.rst
   common_pitfalls.rst
   Dataset loading utilities <datasets/index.rst>
   developers_utils.rst
   zzz_references.rst
